@@ -234,7 +234,7 @@ class Experiment:
             'description': self.description,
             'topology': self.topology,
             'processes': serialize_value(self.processes),
-            'state': self.state.get_config()
+            'state': serialize_value(self.state.get_config())
         }
         emit_config = {
             'table': 'configuration',
